==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/core-utils/lumina-search/i18n/lumina-search_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>ConfigUI</name>
    <message>
        <location filename="../ConfigUI.ui" line="14"/>
        <source>Search Configuration</source>
        <translation>Configuración de la Búsqueda</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="20"/>
        <source>Start Search:</source>
        <translation>Iniciar Búsqueda:</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="39"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="48"/>
        <source>Excluded Directories</source>
        <translation>Directorios Excluídos</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="119"/>
        <source>Save as Defaults</source>
        <translation>Guardar como Predeterminado</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="41"/>
        <source>Select Search Directory</source>
        <translation>Seleccione Directorio de Búsqueda</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="54"/>
        <source>Exclude Directories</source>
        <translation>Excluír Directorios</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Search For...</source>
        <translation>Buscar…</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="23"/>
        <source>Type to search</source>
        <translation>Escriba para buscar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="30"/>
        <source>Configure search parameters</source>
        <translation>Configurar parámetros de búsqueda</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="40"/>
        <source>Stop Active Search</source>
        <translation>Detener Búsqueda Activa</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="54"/>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="64"/>
        <source>Files or Directories</source>
        <translation>Archivos o Directorios</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="88"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Launch Item</source>
        <translation>Lanzar Elemento</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="119"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="122"/>
        <location filename="../MainUI.ui" line="125"/>
        <source>Save Screenshot</source>
        <translation>Guardar Captura de Pantalla</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="136"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="141"/>
        <source>Snap</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="144"/>
        <source>Take new snapshot</source>
        <translation>Tomar nueva captura de pantalla</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="31"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="98"/>
        <source>Search: %1 -- Smart: %2</source>
        <translation>Búsqueda: %1 -- Inteligente: %2</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="101"/>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="101"/>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
</context>
<context>
    <name>Worker</name>
    <message>
        <location filename="../Worker.cpp" line="42"/>
        <source>Searching: %1</source>
        <translation>Buscando: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="64"/>
        <source>Starting Search: %1</source>
        <translation>Comenzando Búsqueda: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="112"/>
        <source>Search Finished</source>
        <translation>Búsqueda Finalizada</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/core-utils/lumina-search/i18n/lumina-search_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>ConfigUI</name>
    <message>
        <location filename="../ConfigUI.ui" line="14"/>
        <source>Search Configuration</source>
        <translation>Configuración de la Búsqueda</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="20"/>
        <source>Start Search:</source>
        <translation>Iniciar Búsqueda:</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="39"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="48"/>
        <source>Excluded Directories</source>
        <translation>Directorios Excluídos</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="119"/>
        <source>Save as Defaults</source>
        <translation>Guardar como Predeterminado</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="41"/>
        <source>Select Search Directory</source>
        <translation>Seleccione Directorio de Búsqueda</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="54"/>
        <source>Exclude Directories</source>
        <translation>Excluír Directorios</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Search For...</source>
        <translation>Buscar…</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="23"/>
        <source>Type to search</source>
        <translation>Escriba para buscar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="30"/>
        <source>Configure search parameters</source>
        <translation>Configurar parámetros de búsqueda</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="40"/>
        <source>Stop Active Search</source>
        <translation>Detener Búsqueda Activa</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="54"/>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="64"/>
        <source>Files or Directories</source>
        <translation>Archivos o Directorios</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="88"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Launch Item</source>
        <translation>Lanzar Elemento</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="119"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="122"/>
        <location filename="../MainUI.ui" line="125"/>
        <source>Save Screenshot</source>
        <translation type="unfinished">Guardar la Captura de Pantalla</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="136"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="141"/>
        <source>Snap</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="144"/>
        <source>Take new snapshot</source>
        <translation>Tomar nueva captura de pantalla</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="31"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="98"/>
        <source>Search: %1 -- Smart: %2</source>
        <translation>Búsqueda: %1 -- Inteligente: %2</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="101"/>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="101"/>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
</context>
<context>
    <name>Worker</name>
    <message>
        <location filename="../Worker.cpp" line="42"/>
        <source>Searching: %1</source>
        <translation>Buscando: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="64"/>
        <source>Starting Search: %1</source>
        <translation>Comenzando Búsqueda: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="112"/>
        <source>Search Finished</source>
        <translation>Búsqueda Finalizada</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
